@@ -1,10 +1,8 @@
 use anyhow::Result;
 use rsdns::{
-    constants::RType,
+    constants::Type,
     resolvers::{ProtocolStrategy, Recursion, ResolverConfig},
 };
-#[cfg(unix)]
-use std::io::{BufRead, BufReader};
 use std::{
     net::{IpAddr, SocketAddr},
     process::exit,
@@ -71,14 +69,14 @@ pub struct Args {
     ///                 is considered as query type. Trailing dot can be
     ///                 used to disambiguate a query name (A.).
     ///
-    /// +udp          - sets the Udp protocol strategy.
-    ///                 UDP is preferred for all queries including ANY.
+    /// +udp          - sets the Udp protocol strategy. UDP is used by default.
+    ///                 Truncated responses are retried using TCP.
     ///
     /// +tcp          - sets the Tcp protocol strategy.
     ///                 Only TCP is used for all queries.
     ///
     /// +notcp        - sets NoTcp protocol strategy. Only UDP is used.
-    ///                 Truncated queries are returned as is.
+    ///                 Truncated queries are returned as is, without retry.
     ///
     /// +[no]rec      - enables (disables) recursive query.
     ///                 Queries are recursive by default.
@@ -130,29 +128,20 @@ impl Args {
     }
 
     fn list_nameservers() -> Result<()> {
-        cfg_if::cfg_if! {
-            if #[cfg(unix)] {
-                let dns_servers = Self::load_resolv_conf()?;
-                for addr in dns_servers.iter() {
-                    println!("{}", addr);
-                }
-            } else if #[cfg(windows)] {
-                let dns_servers = crate::win::get_dns_servers()?;
-                for addr in dns_servers.iter() {
-                    println!("{}", addr);
-                }
-            }
+        let dns_servers = crate::os_nameservers()?;
+        for addr in dns_servers.iter() {
+            println!("{}", addr);
         }
         Ok(())
     }
 
-    pub fn parse(&mut self) -> Result<(ResolverConfig, RType, Vec<String>)> {
-        let mut protocol_strategy = ProtocolStrategy::Default;
+    pub fn parse(&mut self) -> Result<(ResolverConfig, Type, Vec<String>)> {
+        let mut protocol_strategy = ProtocolStrategy::Udp;
         let mut nameserver_ip_addr: Option<IpAddr> = None;
         let mut recursion = Recursion::On;
         let mut short = false;
         let mut free_args = Vec::new();
-        let mut qtype = RType::A;
+        let mut qtype = Type::A;
 
         for a in self.positional.iter() {
             match a.as_str() {
@@ -170,8 +159,8 @@ impl Args {
                         exit(1);
                     }
                 },
-                s if RType::from_str(&s.to_uppercase()).is_ok() => {
-                    qtype = RType::from_str(&s.to_uppercase()).unwrap()
+                s if Type::from_str(&s.to_uppercase()).is_ok() => {
+                    qtype = Type::from_str(&s.to_uppercase()).unwrap()
                 }
                 _ => free_args.push(a.clone()),
             }
@@ -179,7 +168,7 @@ impl Args {
 
         self.short = short;
 
-        if !qtype.is_data_type() && qtype != RType::Any {
+        if !qtype.is_data_type() && qtype != Type::Any {
             eprintln!("only data-type queries are supported or ANY: {}", qtype);
             exit(1);
         }
@@ -187,33 +176,17 @@ impl Args {
         let nameserver = match nameserver_ip_addr {
             Some(addr) => SocketAddr::from((addr, self.port)),
             None => {
-                cfg_if::cfg_if! {
-                    if #[cfg(unix)] {
-                        let nameservers = match Self::load_resolv_conf() {
-                            Ok(v) => v,
-                            Err(_) => Vec::new(),
-                        };
-                    } else if #[cfg(windows)] {
-                        let nameservers = match crate::win::get_dns_servers() {
-                            Ok(v) => v,
-                            Err(_) => Vec::new(),
-                        };
-                    } else {
-                        let nameservers = Vec::<IpAddr>::new();
-                    }
-                };
-
-                if nameservers.is_empty() {
+                if let Ok(v) = crate::os_nameservers() {
+                    SocketAddr::from((v[0], self.port))
+                } else {
                     eprintln!("no nameservers");
                     exit(1);
                 }
-
-                SocketAddr::from((nameservers[0], self.port))
             }
         };
 
         #[allow(unused_mut)]
-        let mut conf = ResolverConfig::new(nameserver)
+        let mut conf = ResolverConfig::with_nameserver(nameserver)
             .set_protocol_strategy(protocol_strategy)
             .set_recursion(recursion)
             .set_query_timeout(if self.query_timeout > 0 {
@@ -230,35 +203,4 @@ impl Args {
 
         Ok((conf, qtype, free_args))
     }
-
-    #[cfg(unix)]
-    fn load_resolv_conf() -> Result<Vec<IpAddr>> {
-        let mut addr_list = Vec::new();
-
-        let f = std::fs::File::open("/etc/resolv.conf")?;
-        for line in BufReader::new(f).lines() {
-            let line = line?;
-            let trimmed = line.trim();
-
-            if trimmed.is_empty() || trimmed.starts_with('#') {
-                continue;
-            }
-
-            let mut parts = trimmed.split_whitespace();
-            if let Some(conf_option) = parts.next() {
-                match conf_option {
-                    "nameserver" => {
-                        if let Some(address) = parts.next() {
-                            if let Ok(ip_addr) = IpAddr::from_str(address) {
-                                addr_list.push(ip_addr);
-                            }
-                        }
-                    }
-                    _ => continue,
-                }
-            }
-        }
-
-        Ok(addr_list)
-    }
 }
