@@ -5,7 +5,7 @@ use crate::{
 use anyhow::Result;
 use chrono::{DateTime, Local};
 use rsdns::{
-    constants::RType,
+    constants::Type,
     message::{reader::MessageReader, Header},
     records::data::RecordData,
     resolvers::ResolverConfig,
@@ -32,7 +32,7 @@ struct Sizes {
 pub struct Output<'a, 'b, 'c, 'd> {
     args: &'a Args,
     qname: &'b str,
-    qtype: RType,
+    qtype: Type,
     msg: &'c [u8],
     ts: SystemTime,
     elapsed: Duration,
@@ -52,7 +52,7 @@ impl<'a, 'b, 'c, 'd> Output<'a, 'b, 'c, 'd> {
     pub fn new(
         args: &'a Args,
         qname: &'b str,
-        qtype: RType,
+        qtype: Type,
         msg: &'c [u8],
         ts: SystemTime,
         elapsed: Duration,
@@ -200,13 +200,13 @@ impl<'a, 'b, 'c, 'd> Output<'a, 'b, 'c, 'd> {
                 RecordData::Ptr(ref ptr) => RDataFmt::fmt(&mut output, ptr)?,
                 RecordData::Mx(ref mx) => RDataFmt::fmt(&mut output, mx)?,
                 RecordData::Txt(ref txt) => RDataFmt::fmt(&mut output, txt)?,
+                RecordData::Hinfo(ref hinfo) => RDataFmt::fmt(&mut output, hinfo)?,
                 RecordData::Wks(_)
                 | RecordData::Null(_)
                 | RecordData::Mr(_)
                 | RecordData::Mg(_)
                 | RecordData::Mb(_)
                 | RecordData::Mf(_)
-                | RecordData::Hinfo(_)
                 | RecordData::Minfo(_)
                 | RecordData::Md(_) => write!(&mut output, "OBSOLETE RTYPE")?,
             }
